pub struct DynamicTupleStruct { /* private fields */ }Expand description
A tuple struct which allows fields to be added at runtime.
Implementations
Sourceimpl DynamicTupleStruct
impl DynamicTupleStruct
Sourcepub fn set_represented_type(
&mut self,
represented_type: Option<&'static TypeInfo>,
)
pub fn set_represented_type( &mut self, represented_type: Option<&'static TypeInfo>, )
Sets the type to be represented by this DynamicTupleStruct.
Panics
Panics if the given type is not a TypeInfo::TupleStruct.
Sourcepub fn insert_boxed(&mut self, value: Box<dyn PartialReflect>)
pub fn insert_boxed(&mut self, value: Box<dyn PartialReflect>)
Appends an element with value value to the tuple struct.
Sourcepub fn insert<T: PartialReflect>(&mut self, value: T)
pub fn insert<T: PartialReflect>(&mut self, value: T)
Appends a typed element with value value to the tuple struct.